@@ -3,7 +3,7 @@ import numpy as np
 from .common import Jacobian, NumericalJacobian, UserDefinedJacobian, EPS
 from numba import njit
 from abc import ABC, abstractmethod
-from .interface import Interface, _JitHelper
+from .interface import Interface
 from .common import select_initial_step
 from scipy.linalg import lu_solve as lu_solve_scipy, lu_factor as lu_factor_scipy
 from .linalg.lapack.lapack_python import lu_factor, lu_solve
@@ -164,9 +164,6 @@ class RK45(BaseMethod):
 
             tnew = t+dt
 
-            if len(y) == 0:
-                return tnew, y, True, 1, _solve_state, max_factor
-
             k = np.zeros((rk_steps+2, len(y)))
             k[0,:] = f0*dt
 
@@ -245,15 +242,12 @@ class BDF(BaseMethod):
 
         try:
             self.interface.get_jacobian(0)
-            jacobian = _JitHelper.jithelper(UserDefinedJacobian, jit=self.use_jit)
-            jac: UserDefinedJacobian = jacobian(interface=self.interface)
+            jac: UserDefinedJacobian = UserDefinedJacobian(interface=self.interface)
             self.J = jac.get_jacobian(0)
 
         except NotImplementedError:
-            jacobian = _JitHelper.jithelper(NumericalJacobian, jit=self.use_jit)
-            jac: NumericalJacobian = jacobian(interface=self.interface, tolerance=abs_tol)
+            jac: NumericalJacobian = NumericalJacobian(interface=self.interface, tolerance=abs_tol)
             self.J = jac.get_jacobian(0)
-
         self.jac = jac
         self.initial_step = select_initial_step(self.interface, 0, self.y0,
                                                            1, 1, rel_tol,
@@ -423,7 +417,6 @@ class BDF(BaseMethod):
                 if update_LU:
                     jac = np.identity(n) - c * J
                     LU, ipiv = _lu_factor(jac)
-                    #LU = lu_factor_scipy(jac)
                     update_LU = False
 
                 converged, rate, ynew, d, stat, inner_iter = \
@@ -500,6 +493,7 @@ class BDF(BaseMethod):
 
     def get_solver_state(self):
         n = len(self.y0)
+        self.jac._jit(jit=self.use_jit)
         self.jac.reset()
         self.J = self.jac.get_jacobian(0)
         c = self.initial_step / (self.alpha[1])
@@ -519,7 +513,7 @@ class BDF(BaseMethod):
                  self.D,
                  self.initial_step,
                  1,
-                 self.jac,
+                 self.jac._compiled_model,
                  tuple(self._I),
                  tuple(self._J),
                  tuple(self._U)
